import unittest
from random_words_genrator.words import generate_random_words

class TestWords(unittest.TestCase):
   def test_generate_random_words(self):
      words = generate_random_words()
      self.assertEqual(len(words), 8)
      for word in words:
         self.assertIsInstance(word, str)
         
   def test_generate_random_words_with_specific_number(self):
      """Teste que la fonction génère le nombre spécifié de mots."""
      num_words = 5
      words = generate_random_words(num_words)
      self.assertEqual(len(words), num_words)

   def test_generate_random_words_with_zero(self):
      """Teste que la fonction gère correctement un nombre de mots de 0."""
      num_words = 0
      words = generate_random_words(num_words)
      self.assertEqual(len(words), 0)

if __name__ == '__main__':
    unittest.main()



import random
from typing import List

def generate_random_words(num_words: int = 8) -> List[str]:
   """
   Génère un nombre spécifié de mots français au hasard.

   Args:
      num_words (int, optional): Le nombre de mots à générer. Defaults to 8.

   Returns:
      List[str]: Une liste de mots français.

   Raises:
      ValueError: Si num_words est supérieur à 20 ou inférieur à 0.
   """
   
   if num_words > 20 or num_words < 0:
      raise ValueError("Le nombre de mots doit être entre 0 et 20.")
   
   french_words = [
         "dixième", "canari", "carotte", "escalier", "Mécanique", "havre", "nostalgie", "robe", "bombe", "visite", "faire",
         "united", "autour", "symbole", "astrologie", "pirate", "funiculaire", "balcon", "cyclope", "alpiniste",
         "terrasse", "sensible", "coupable", "somnambule", "bermudes", "soutien", "etriers", "jeune", "marié", "radical",
         "bienveillant", "puzzle", "troupes", "infini", "lance", "papillon", "gala", "croix", "guerre", "portable",
         "moyenne", "couture", "tire-bouchon", "galactique", "lourdaud", "avaler", "minuscule", "picorer", "immersion", "poker",
         "bandeau", "court", "assistant", "dinosaure", "africain", "naphte", "fiasco", "routes", "grenouille", "humain", "cidre",
         "lit", "chaussette", "presque", "attitude", "été", "projet", "stéréo", "tourbillon", "cartographie", "jumelles", "bronze",
         "nuque", "ballon", "manille", "harpon", "pompiers", "les", "caissier", "mannequin", "raccommoder", "hypnotiser", "mer",
         "fibre", "octobre", "limace", "paysage", "invisible", "moto", "tornade", "peste", "timbre", "hypnotise", "bronzer",
         "lagon", "coq", "surmonter", "caillot", "lame", "champion", "stylo", "myrtille", "afrique", "sénat", "senteur",
         "abri", "absurde", "accent", "accord", "accrocher", "accumuler", "aciduler", "acoustique", "acteur", "adhérer", "adjectif",
         "admirer", "adopter", "adulte", "aérodrome", "afficher", "agacer", "agglomérer", "agiter", "agréable", "aigle", "aigre",
         "aiguille", "aimanter", "air", "aisance", "alcool", "alerte", "algèbre", "alliance", "alligator", "allumer", "alphabet",
         "ambiance", "ambition", "améliorer", "amnésie", "amoureux", "amphithéâtre", "analyser", "anarchie", "anatomie", "ancêtre",
         "ancien", "angoisse", "animal", "anniversaire", "annonce", "annuler", "antenne", "antidote", "antique", "antisémite",
         "aperçu", "apologiser", "appareil", "appeler", "apporter", "apprendre", "appuyer", "aquarium", "arbitre", "arbre", "arcade",
         "arche", "archevêque", "archer", "architecte", "arctic", "aréna", "argent", "argenterie", "arme", "armure", "aromatique",
         "arracher", "arriver", "arroser", "artiste", "article", "aspect", "asperger", "aspirateur", "assaut", "assurer", "astuce",
         "atlas", "atome", "atout", "attacher", "attelage", "attendre", "attirer", "attraper", "auberge", "aubaine", "audace",
         "audible", "auditeur", "augmenter", "auteur", "autoriser", "autruche", "avalanche", "avancer", "avare", "avatar", "aventure",
         "avion", "avis", "avocat", "avouer", "axe", "axiomatique", "azimut", "azur", "babysitter", "bac", "baccarat",
         "bactérie", "badge", "baguette", "baiser", "baisser", "balade", "balcon", "balise", "ballet", "bambou", "banane",
         "banc", "bande", "banlieue", "banque", "banquier", "barbier", "barde", "baril", "barman", "barrage", "barre",
         "barrière", "baryton", "bascule", "bataille", "bateau", "batterie", "baver", "bavette", "beau", "beauté", "bébé",
         "bêche", "bêler", "bêta", "bible", "bicyclette", "bidon", "bifteck", "bifurquer", "bille", "billard", "binaire",
         "biologie", "biopsie", "biotope", "biscuit", "bison", "bistouri", "bivouac", "blague", "blanc", "blessé", "blinder",
   ]
   chosen_words = set()
   while len(chosen_words) < num_words:
      word = random.choice(french_words)
      chosen_words.add(word)
   return list(chosen_words)
 


from setuptools import setup, find_packages

setup(
    name="random_words_generator_fr",
    version="0.3",
    packages=find_packages(),
    install_requires=[
        # Aucune dépendance externe nécessaire
    ],
    extras_require={
        "dev": [
            # Ajoutez ici les dépendances de développement, si nécessaire
            # Par exemple : "pytest>=6.2.2", "black>=20.8b1"
        ],
    },
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
   python_requires=">=3.6",
   description="Génère un nombre spécifié de mots français au hasard, entre 0 et 20 mots. Par défaut, génère 8 mots. utile pour divers projets nécessitant des mots français aléatoires. Permet de générer des mots pour des jeux, des tests de vocabulaire, des noms de fichiers uniques, et bien plus encore.",
   long_description=open("README.md" , encoding="utf-8").read(),
   long_description_content_type="text/markdown",
   author="killymeed",
   author_email="gowleytizie@proton.me",
   keywords="mots français aléatoires générateur de mots",
)
